@@ -312,7 +312,8 @@ def sort_dict_list_by_list(dict_list: List[dict], sort_value_list: List[str], na
     return ordered_list
 
 
-def find_all_parents(tree, target_list, parent_key="parent_id", key="id", children_key="children", value_key="name"):
+def find_all_parents(tree: list, target_list: list, parent_key: str = "parent_id", key: str = "id",
+                     children_key: str = "children", value_key: str = None):
     """
     查找树形结构中每个目标元素的所有父级（包括间接父级）
 
@@ -333,7 +334,7 @@ def find_all_parents(tree, target_list, parent_key="parent_id", key="id", childr
                 children_key: node.get(children_key, []),
                 key: node[key]
             }
-            if value_key not in node:
+            if value_key and value_key not in node:
                 node[value_key] = node.get(value_key, '')
             if children_key in node and node[children_key]:
                 build_map(node[children_key])
@@ -352,7 +353,11 @@ def find_all_parents(tree, target_list, parent_key="parent_id", key="id", childr
         parent_id = node_info[parent_key]
         if parent_id and parent_id in node_map:
             parent_info = node_map.get(parent_id, {}) or {}
-            parents_list.append(parent_info.get(value_key, {}))
+            if value_key:
+                if parent_info.get(value_key, {}):
+                    parents_list.append(parent_info.get(value_key, {}))
+            else:
+                parents_list.append(parent_info)
             return find_parents(parent_id, parents_list)
         return parents_list
 
@@ -368,8 +373,8 @@ def find_all_parents(tree, target_list, parent_key="parent_id", key="id", childr
     return result
 
 
-def find_all_children(tree: list, target_list, parent_key="parent_id", key="id", children_key="children",
-                      value_key="name"):
+def find_all_children(tree: list, target_list: list, parent_key: str = "parent_id", key: str = "id",
+                      children_key: str = "children", value_key: str = None):
     """
     查找树形结构中每个目标元素的所有子级（包括间接子级）
 
@@ -390,7 +395,7 @@ def find_all_children(tree: list, target_list, parent_key="parent_id", key="id",
                 children_key: node.get(children_key, []),
                 key: node[key]
             }
-            if value_key not in node:
+            if value_key and value_key not in node:
                 node[value_key] = node.get(value_key, '')
             if children_key in node and node[children_key]:
                 build_map(node[children_key])
@@ -405,7 +410,11 @@ def find_all_children(tree: list, target_list, parent_key="parent_id", key="id",
         # 查找所有直接子节点
         for node_id, node_info in node_map.items():
             if node_info[parent_key] == parent_id:
-                children_list.append(node_info.get(value_key, ''))
+                if value_key:
+                    if node_info.get(value_key, ''):
+                        children_list.append(node_info.get(value_key, ""))
+                else:
+                    children_list.append(node_info)
                 # 递归查找孙子节点
                 find_children(node_id, children_list)
         return children_list
